==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/frm_task.js <==
_me = frm_task.prototype;
function frm_task(){};

_me.__constructor = function() {
	var me = this;
	this._defaultSize();
	this._draw('frm_task', 'main');
	this.__initForm('TASK::TASK');

	var tab1 = this.maintab.tab1;

	if (!this._sItemID) {
		tab1.EVNSTARTDATE._disabled(true);
		tab1.EVNENDDATE._disabled(true);
	}
	
	tab1.X_EVNCOMPLETE._fill({'0':'0','25':'25','50':'50','75':'75','100':'100'});
	tab1.X_STARTS._onclick = function() { tab1.EVNSTARTDATE._disabled(!this._value()); }
	tab1.X_ENDS._onclick = function() { tab1.EVNENDDATE._disabled(!this._value()); }
	tab1.EVNSTATUS._onchange = function() { me.__setEvncomplete(); }
	tab1.X_EVNCOMPLETE._onchange = function() { me.__setEvnstatus(); }
};

_me.__setEvncomplete = function(sValue){
	var tab1 = this.maintab.tab1;

	switch (tab1.EVNSTATUS._value()[0]){
		case 'S':
			tab1.X_EVNCOMPLETE._value(0);
			tab1.X_EVNCOMPLETE._disabled(true);
			break;
		case 'D':
			tab1.X_EVNCOMPLETE._value(100);
			tab1.X_EVNCOMPLETE._disabled(true);
			break;
		default:
			if (Is.Defined(sValue)) tab1.X_EVNCOMPLETE._value(sValue);
			tab1.X_EVNCOMPLETE._disabled(false);
			break;
	}
};

_me.__setEvnstatus = function() {
	var tab1 = this.maintab.tab1;
	var curval = parseInt(tab1.X_EVNCOMPLETE._value());
	
	if (!Is.Number(curval) || curval <= 0)
		tab1.EVNSTATUS._value('S');
	else
	if (curval >= 100)
		tab1.EVNSTATUS._value('D');
};

_me.__loadItems = function() {
	var me = this;

	var tab1 = this.maintab.tab1;
	loadDataIntoForm(tab1,this._aValues);

	//Copy contact name into window title
	tab1.EVNTITLE._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
			    sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
		    me._title('TASK::TASK');
	};
	tab1.EVNTITLE._onkeyup();
	
	if (Is.Defined(this._aValues['EVNSTARTDATE']) && this._aValues['EVNSTARTDATE'] != 'undefined' && this._aValues['EVNSTARTDATE'] != 0) {
		tab1.X_STARTS._value(true);
		tab1.EVNSTARTDATE._disabled(false);
	} else {
		tab1.X_STARTS._value(false);
		tab1.EVNSTARTDATE._value('empty');
		tab1.EVNSTARTDATE._disabled(true);
	}
	if (Is.Defined(this._aValues['EVNENDDATE']) && this._aValues['EVNENDDATE'] != 'undefined' && this._aValues['EVNENDDATE'] != 0) {
		tab1.X_ENDS._value(true);
		tab1.EVNENDDATE._disabled(false);
	} else {
		tab1.X_ENDS._value(false);
		tab1.EVNENDDATE._value('empty');
		tab1.EVNENDDATE._disabled(true);
	}
	
	if (inArray(['S', 'D', 'L', 'A', 'N'], this._aValues['EVNSTATUS']) == -1) tab1.EVNSTATUS._value('N');
	this.__setEvncomplete(this._aValues['EVNCOMPLETE']);
	
	if (!this._aValues['EVN_ID']) tab1.EVNSHARETYPE._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','task_sharing'));
	
	// TAB2 (recurrence)
	this.maintab.tab2._onactive = function (bFirstTime) {
		if (bFirstTime) {
			var recurrence = shiftObject(me._aValues['RECURRENCES']);
			if (recurrence != null)
				this.X_REPEATING._value(recurrence);
				
			if (Is.Defined(me._aValues['EVNENDDATE'])) {
				var rawDate = parseJulianDate(me._aValues['EVNENDDATE']); 
				var date = new Date(rawDate.year, rawDate.month-1, rawDate.day);
				this.X_REPEATING._setDate(date);
			}
		}
	}
	
	// TAB3 (Reminders)
	this.maintab.tab3._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['REMINDERS']))
			this.X_REMINDERS._value(me._aValues['REMINDERS']);
	}
	
	// TAB4 (attachments)
	this.maintab.tab4._onactive = function (bFirstTime) {
		if (bFirstTime){
			if (Is.Defined(me._aValues['ATTACHMENTS']))
				this.X_ATTACHMENTS._value({'path': me._sAccountID+'/'+me._sFolderID+'/'+me._sItemID, 'values': me._aValues['ATTACHMENTS']});
			else
			if (me._aValues['PUSH_ATTACHMENTS'])
				this.X_ATTACHMENTS.__addItems(me._aValues['PUSH_ATTACHMENTS']);
		}
	}

	if (me._aValues['PUSH_ATTACHMENTS'])
		this.maintab.tab4._active();
};

_me.__saveItems = function(aValues) {
	var tab1 = this.maintab.tab1;
	if (!tab1.X_STARTS._value()) aValues['values']['EVNSTARTDATE'] = 0;
	if (!tab1.X_ENDS._value()) aValues['values']['EVNENDDATE'] = 0;
	aValues['values']['EVNCOMPLETE'] = tab1.X_EVNCOMPLETE._value();
	
	var addon;
	// TAB2
	if (this.maintab.tab2.X_REPEATING && !Is.Empty(addon = this.maintab.tab2.X_REPEATING._value()))
		aValues['RECURRENCES'] = [addon];

	// TAB3
	if (this.maintab.tab3.X_REMINDERS && !Is.Empty(addon = this.maintab.tab3.X_REMINDERS._value()))
		aValues['REMINDERS'] = addon;

	// TAB4
	if (this.maintab.tab4.X_ATTACHMENTS && !Is.Empty(addon = this.maintab.tab4.X_ATTACHMENTS._value()))
		aValues['ATTACHMENTS'] = addon;
};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/frm_task.js <==
_me = frm_task.prototype;
function frm_task(){};

_me.__constructor = function() {
	var me = this;
	this._defaultSize();


    var aData = {};
	var tmpf = Path.split(this._sFolderID)[0];
    if (dataSet.get('folders',[this._sAccountID,tmpf,'TYPE'])=='A')
		aData.owner = tmpf;
	else
	    aData.owner = this._sAccountID;

    //this.__owner = aData.owner;
    
	this._draw('frm_task', 'main', aData);
	this.__initForm('TASK::TASK');

	var tab1 = this.maintab.tab1;

	if (!this._sItemID) {
		tab1.EVNSTARTDATE._disabled(true);
		tab1.EVNENDDATE._disabled(true);
	}
	
	tab1.X_EVNCOMPLETE._fill({'0':'0','25':'25','50':'50','75':'75','100':'100'});


	tab1.X_STARTS._onclick = function() {
		tab1.EVNSTARTDATE._disabled(!this._value());
		if (this._value())
			tab1.EVNSTARTDATE._ondateselect();
	};
	tab1.X_ENDS._onclick = function() {
		tab1.EVNENDDATE._disabled(!this._value());
		if (this._value())
			tab1.EVNENDDATE._ondateselect();
	};

    tab1.EVNSTARTDATE._ondateselect = function(){
		var tmp0 = this._getObjectDate();
		var tmp1 = this._parent.EVNENDDATE._getObjectDate();
		
		if (!this._parent.EVNENDDATE._disabled() && tmp0 && tmp1 && tmp0.getTime() < tmp1.getTime())
			this._parent.EVNENDDATE._value(this._value(), true);
	};
    tab1.EVNENDDATE._ondateselect = function(){
		var tmp0 = this._getObjectDate();
		var tmp1 = this._parent.EVNSTARTDATE._getObjectDate();
		
		if (!this._parent.EVNSTARTDATE._disabled() && tmp0 && tmp1 && tmp0.getTime() > tmp1.getTime())
			this._parent.EVNSTARTDATE._value(this._value(), true);
	};


	tab1.EVNSTATUS._onchange = function() { me.__setEvncomplete(); }
	tab1.X_EVNCOMPLETE._onchange = function() { me.__setEvnstatus(); }
};

_me.__setEvncomplete = function(sValue){
	var tab1 = this.maintab.tab1;

	switch (tab1.EVNSTATUS._value()[0]){
		case 'S':
			tab1.X_EVNCOMPLETE._value(0);
			tab1.X_EVNCOMPLETE._disabled(true);
			break;
		case 'D':
			tab1.X_EVNCOMPLETE._value(100);
			tab1.X_EVNCOMPLETE._disabled(true);
			break;
		default:
			if (Is.Defined(sValue)) tab1.X_EVNCOMPLETE._value(sValue);
			tab1.X_EVNCOMPLETE._disabled(false);
			break;
	}
};

_me.__setEvnstatus = function() {
	var tab1 = this.maintab.tab1;
	var curval = parseInt(tab1.X_EVNCOMPLETE._value());
	
	if (!Is.Number(curval) || curval <= 0)
		tab1.EVNSTATUS._value('S');
	else
	if (curval >= 100)
		tab1.EVNSTATUS._value('D');
};

_me.__loadItems = function() {
	var me = this;

	var tab1 = this.maintab.tab1;
	loadDataIntoForm(tab1,this._aValues);

	//Copy contact name into window title
	tab1.EVNTITLE._onkeyup = function(){
		var sTitle = this._value();
		if (sTitle){
			if (sTitle.length>32)
			    sTitle = sTitle.substr(0,32)+'...';

			me._title(sTitle,true);
		}
		else
		    me._title('TASK::TASK');
	};
	tab1.EVNTITLE._onkeyup();
	
	if (Is.Defined(this._aValues['EVNSTARTDATE']) && this._aValues['EVNSTARTDATE'] != 'undefined' && this._aValues['EVNSTARTDATE'] != 0) {
		tab1.X_STARTS._value(true);
		tab1.EVNSTARTDATE._disabled(false);
	} else {
		tab1.X_STARTS._value(false);
		tab1.EVNSTARTDATE._value('empty');
		tab1.EVNSTARTDATE._disabled(true);
	}
	if (Is.Defined(this._aValues['EVNENDDATE']) && this._aValues['EVNENDDATE'] != 'undefined' && this._aValues['EVNENDDATE'] != 0) {
		tab1.X_ENDS._value(true);
		tab1.EVNENDDATE._disabled(false);
	} else {
		tab1.X_ENDS._value(false);
		tab1.EVNENDDATE._value('empty');
		tab1.EVNENDDATE._disabled(true);
	}
	
	if (inArray(['S', 'D', 'L', 'B', 'N'], this._aValues['EVNSTATUS']) == -1) tab1.EVNSTATUS._value('N');
	this.__setEvncomplete(this._aValues['EVNCOMPLETE']);
	
	if (!this._aValues['EVN_ID']) tab1.EVNSHARETYPE._value(GWOthers.getItem('DEFAULT_CALENDAR_SETTINGS','task_sharing'));
	
	// TAB2 (recurrence)
	this.maintab.tab2._onactive = function (bFirstTime) {
		if (bFirstTime) {
			var recurrence = shiftObject(me._aValues['RECURRENCES']);
			if (recurrence != null)
				this.X_REPEATING._value(recurrence);
				
			if (Is.Defined(me._aValues['EVNENDDATE'])) {
				var rawDate = parseJulianDate(me._aValues['EVNENDDATE']); 
				var date = new Date(rawDate.year, rawDate.month-1, rawDate.day);
				this.X_REPEATING._setDate(date);
			}
		}
	}
	
	// TAB3 (Reminders)
	this.maintab.tab3._onactive = function (bFirstTime) {
		if (bFirstTime && Is.Defined(me._aValues['REMINDERS']))
			this.X_REMINDERS._value(me._aValues['REMINDERS']);
	}

	// TAB5 (Attendee)
	this.maintab.tab5._onactive = function (bFirstTime) {
		if (bFirstTime){
			if (Is.Defined(me._aValues['CONTACTS']))
				this.X_ATTENDEES._value(me._aValues['CONTACTS']);
			
			if (me._aValues['EVNFLAGS']&1)
				this.X_ATTENDEES.invitation._value(1);
			else
			if (me._aValues['EVNFLAGS']&2)
				this.X_ATTENDEES.invitation._disabled(true);
		}
	}

	// TAB4 (attachments)
	this.maintab.tab4._onactive = function (bFirstTime) {
		if (bFirstTime){
			if (Is.Defined(me._aValues['ATTACHMENTS']))
				this.X_ATTACHMENTS._value({'path': me._sAccountID+'/'+me._sFolderID+'/'+me._sItemID, 'values': me._aValues['ATTACHMENTS']});
			else
			if (me._aValues['PUSH_ATTACHMENTS'])
				this.X_ATTACHMENTS.__addItems(me._aValues['PUSH_ATTACHMENTS']);
		}
	}

	if (me._aValues['PUSH_ATTACHMENTS'])
		this.maintab.tab4._active();
};

_me.__saveItems = function(aValues) {
	var tab1 = this.maintab.tab1;
	if (!tab1.X_STARTS._value()) aValues['values']['EVNSTARTDATE'] = 0;
	if (!tab1.X_ENDS._value()) aValues['values']['EVNENDDATE'] = 0;
	aValues['values']['EVNCOMPLETE'] = tab1.X_EVNCOMPLETE._value();
	
	var addon;
	// TAB2
	if (this.maintab.tab2.X_REPEATING && !Is.Empty(addon = this.maintab.tab2.X_REPEATING._value()))
		aValues['RECURRENCES'] = [addon];

	// TAB3
	if (this.maintab.tab3.X_REMINDERS && !Is.Empty(addon = this.maintab.tab3.X_REMINDERS._value()))
		aValues['REMINDERS'] = addon;

	// TAB4
	if (this.maintab.tab4.X_ATTACHMENTS && !Is.Empty(addon = this.maintab.tab4.X_ATTACHMENTS._value()))
		aValues['ATTACHMENTS'] = addon;
		
	// TAB5
	if (this.maintab.tab5.X_ATTENDEES){
		if (!Is.Empty(addon = this.maintab.tab5.X_ATTENDEES._value()))
			aValues['CONTACTS'] = addon;
			
		if (!this.maintab.tab5.X_ATTENDEES.invitation._disabled()){
			aValues['values'].EVNFLAGS = this.maintab.tab5.X_ATTENDEES.invitation._value()?1:'';
			//aValues['values'].EVNORGANIZER = this.__owner;
		}
	}
};
